@@ -27,6 +27,7 @@ import("dayjs/locale/vi");
 import("dayjs/locale/zh-cn");
 import("dayjs/locale/zh-tw");
 import("dayjs/locale/cs");
+import("dayjs/locale/nb");
 
 // All i18n resources specified in the plugin `include` option can be loaded
 // at once using the import syntax
@@ -101,7 +102,6 @@ export function detectLocale() {
     case /^tr\b/.test(locale):
       locale = "tr";
       break;
-    // ua wasnt a valid locale for ukraine
     case /^uk\b/.test(locale):
       locale = "uk";
       break;
@@ -115,6 +115,10 @@ export function detectLocale() {
     case /^nl-be\b/.test(locale):
       locale = "nl-be";
       break;
+    case /^nb\b/.test(locale):
+    case /^no\b/.test(locale):
+      locale = "no";
+      break;
     default:
       locale = "en";
   }
